"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _exportNames = {
  multiply: true,
  Debugger: true
};
exports.Debugger = void 0;
exports.multiply = multiply;

var _reactNative = require("react-native");

var _react = _interopRequireWildcard(require("react"));

var _utils = require("./utils");

Object.keys(_utils).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  if (key in exports && exports[key] === _utils[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _utils[key];
    }
  });
});

var _clipboard = _interopRequireDefault(require("@react-native-clipboard/clipboard"));

var _useShowDebugger = require("./utils/useShowDebugger");

var _DebuggerItem = require("./components/DebuggerItem");

var _styles = require("./styles");

var _state = require("./state");

var _reactNativeDocumentPicker = require("react-native-document-picker");

var _reactNativeSafX = require("react-native-saf-x");

var _reactNativeBlobUtil = _interopRequireDefault(require("react-native-blob-util"));

var _components = require("./components");

Object.keys(_components).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  if (key in exports && exports[key] === _components[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _components[key];
    }
  });
});

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function multiply(a, b) {
  return Promise.resolve(a * b);
}

const Item = _ref => {
  let {
    item
  } = _ref;
  const [visible, setVisible] = (0, _react.useState)(false);

  const handleCopyPress = () => _clipboard.default.setString(JSON.stringify(item));

  const colorByType = (0, _styles.itemColorByType)(item.logType);
  const textColor = {
    color: colorByType
  };
  const iconColor = {
    backgroundColor: colorByType
  };
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _styles.styles.itemWrapper
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _styles.styles.itemHeader
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [_styles.styles.itemIcon, iconColor]
  }), /*#__PURE__*/_react.default.createElement(_reactNative.View, null, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    selectable: true,
    style: [_styles.styles.itemLabel, textColor]
  }, item.label), /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    selectable: true,
    style: [_styles.styles.itemTime, textColor]
  }, item.timestamp), Boolean(item.type) && /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    selectable: true,
    style: [_styles.styles.itemType, textColor]
  }, item.type))), /*#__PURE__*/_react.default.createElement(_reactNative.ScrollView, {
    style: visible ? _styles.styles.itemScrollWrapperVisible : _styles.styles.itemScrollWrapper,
    contentContainerStyle: item.itemScroll,
    horizontal: true
  }, /*#__PURE__*/_react.default.createElement(_DebuggerItem.DebuggerItem, {
    onToggle: setVisible,
    item: item.data
  })), visible && /*#__PURE__*/_react.default.createElement(_reactNative.Pressable, {
    onPress: handleCopyPress,
    style: _styles.styles.itemCopyBtn
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: _styles.styles.itemCopyText
  }, "Copy")));
};

const Separator = () => /*#__PURE__*/_react.default.createElement(_reactNative.View, {
  style: _styles.styles.separator
});

const EmptySection = () => /*#__PURE__*/_react.default.createElement(_reactNative.View, {
  style: _styles.styles.emptyWrapper
}, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
  style: _styles.styles.emptyText
}, "No events captured yet"));

const keyExtractor = _ref2 => {
  let {
    id
  } = _ref2;
  return `${id}`;
};

const renderItem = _ref3 => {
  let {
    item
  } = _ref3;
  return /*#__PURE__*/_react.default.createElement(Item, {
    item: item
  });
};

const Debugger = /*#__PURE__*/_react.default.memo(_ref4 => {
  let {
    getGlobalState
  } = _ref4;
  const [debugItems] = (0, _utils.useDebugItems)();
  const [show] = (0, _useShowDebugger.useShowDebugger)();
  console.log({
    debugItems
  });
  (0, _react.useEffect)(() => {
    _state.DebuggerState.isMounted = true;
    return () => {
      _state.DebuggerState.isMounted = false;
    };
  }, []);
  (0, _react.useEffect)(() => {
    _state.DebuggerState.getGlobalState = getGlobalState;
  }, [getGlobalState]);

  const handleClose = () => (0, _utils.toggleDebugger)(false);

  const handleGetGlobalState = () => getGlobalState && _clipboard.default.setString(JSON.stringify(getGlobalState === null || getGlobalState === void 0 ? void 0 : getGlobalState()));

  const handleExportItems = async () => {
    try {
      /*fetch('https://pastebin.com/api/api_post.php', {
        body: `api_dev_key=clcVbOdfoqzhASuaHaFSLXaiG78XAeRz&api_paste_code=${JSON.stringify(
          debugItems
        )}&api_option=paste&api_paste_private=2&api_user_key=37eb3c9cdd035fbb30c3f1b5a9e4b69b`,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded',
        },
        method: 'POST',
      })
        .then((d) => d.text())
        .then((url) => {
          Clipboard.setString(url);
          Alert.alert(url);
        });*/
      (0, _reactNativeDocumentPicker.pickDirectory)().then(dir => {
        var _dir$uri;

        if (!dir) {
          _clipboard.default.setString(JSON.stringify(debugItems));

          _reactNative.Alert.alert('File saving failed, copied instead');

          return;
        }

        const filePath = `${dir.uri}/qa-debugger-${new Date().toISOString()}.txt`;
        console.log({
          filePath
        });

        if (_reactNative.Platform.OS === 'android' && (_dir$uri = dir.uri) !== null && _dir$uri !== void 0 && _dir$uri.startsWith('content://')) {
          (0, _reactNativeSafX.writeFile)(filePath, JSON.stringify(debugItems)).then(() => {
            _reactNative.Alert.alert('File successfully saved');
          }).catch(() => {
            _clipboard.default.setString(JSON.stringify(debugItems));

            _reactNative.Alert.alert('File saving failed, copied instead');
          });
          return;
        }

        _reactNativeBlobUtil.default.fs.writeFile(filePath, JSON.stringify(debugItems), 'utf8').then(() => {
          _reactNative.Alert.alert('File successfully saved');
        }).catch(() => {
          _clipboard.default.setString(JSON.stringify(debugItems));

          _reactNative.Alert.alert('File saving failed, copied instead');
        });
      }).catch(() => {
        _clipboard.default.setString(JSON.stringify(debugItems));

        _reactNative.Alert.alert('Failed to pick a directory, copied instead');
      });
    } catch {
      _clipboard.default.setString(JSON.stringify(debugItems));

      _reactNative.Alert.alert('Items copied');
    }
  };

  return show ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _styles.styles.wrapper
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _styles.styles.titleWrapper
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: _styles.styles.title
  }, "QA DEBUGGER")), /*#__PURE__*/_react.default.createElement(_reactNative.FlatList, {
    keyExtractor: keyExtractor,
    contentContainerStyle: _styles.styles.flex,
    ItemSeparatorComponent: Separator,
    data: debugItems,
    ListEmptyComponent: EmptySection,
    renderItem: renderItem
  }), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _styles.styles.buttonSection
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Pressable, {
    onPress: handleExportItems,
    style: _styles.styles.button
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: _styles.styles.buttonText
  }, "Export items")), /*#__PURE__*/_react.default.createElement(_reactNative.Pressable, {
    onPress: _utils.resetLogItems,
    style: [_styles.styles.button, _styles.styles.centralButton]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: _styles.styles.buttonText
  }, "Clear")), /*#__PURE__*/_react.default.createElement(_reactNative.Pressable, {
    onPress: handleClose,
    style: _styles.styles.button
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: _styles.styles.buttonText
  }, "Close"))), Boolean(getGlobalState) && /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _styles.styles.buttonSection
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Pressable, {
    onPress: handleGetGlobalState,
    style: _styles.styles.button
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: _styles.styles.buttonText
  }, "Copy global state")))) : null;
});

exports.Debugger = Debugger;
//# sourceMappingURL=index.js.map