"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _exportNames = {
  itemColorByType: true,
  styles: true
};
exports.styles = exports.itemColorByType = void 0;

var _reactNative = require("react-native");

var _constants = require("./constants");

var _utils = require("./utils");

Object.keys(_utils).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  if (key in exports && exports[key] === _utils[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _utils[key];
    }
  });
});

const itemColorByType = type => {
  switch (type || '') {
    case 'success':
      return 'lightgreen';

    case 'error':
      return 'red';

    case 'warning':
      return 'yellow';

    case 'info':
      return 'lightblue';

    default:
      return type;
  }
};

exports.itemColorByType = itemColorByType;

const {
  height
} = _reactNative.Dimensions.get('window');

const styles = _reactNative.StyleSheet.create({
  wrapper: {
    elevation: 100000,
    position: 'absolute',
    left: 0,
    top: 0,
    width: '100%',
    maxHeight: Math.max(height * 0.6, 300),
    backgroundColor: '#000000BB'
  },
  itemWrapper: {
    width: '100%',
    padding: 16,
    paddingBottom: 8
  },
  itemHeader: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center'
  },
  itemIcon: {
    display: 'none',
    marginTop: 8,
    width: 8,
    height: 8,
    borderRadius: 8,
    marginRight: 8,
    alignSelf: 'flex-start'
  },
  itemLabel: {
    fontWeight: 'bold',
    fontSize: 16,
    textAlign: 'center'
  },
  itemTime: {
    fontWeight: 'bold',
    fontSize: 12,
    textAlign: 'center'
  },
  itemType: {
    fontWeight: 'bold',
    textAlign: 'center',
    marginBottom: 8
  },
  itemCopyBtn: {
    position: 'absolute',
    right: 0,
    bottom: 0,
    paddingVertical: 4,
    paddingHorizontal: 16,
    borderLeftWidth: 1,
    borderTopWidth: 1,
    borderColor: _constants.colors.separator
  },
  itemCopyText: {
    color: _constants.colors.textSecondary
  },
  itemScroll: {
    paddingBottom: 8
  },
  itemScrollWrapperVisible: {
    marginBottom: 24
  },
  itemScrollWrapper: {
    marginBottom: 0
  },
  titleWrapper: {
    alignItems: 'center',
    padding: 8
  },
  title: {
    color: 'white',
    fontWeight: 'bold',
    fontSize: 16
  },
  flex: {
    flex: 1
  },
  separator: {
    width: '100%',
    borderTopWidth: 1,
    borderColor: _constants.colors.separator
  },
  emptyWrapper: {
    padding: 16,
    alignItems: 'center',
    justifyContent: 'center'
  },
  emptyText: {
    color: _constants.colors.textSecondary
  },
  buttonText: {
    color: 'white',
    fontWeight: '500'
  },
  button: {
    padding: 8,
    flex: 1,
    alignItems: 'center'
  },
  centralButton: {
    borderLeftWidth: 1,
    borderRightWidth: 1,
    borderColor: _constants.colors.separator
  },
  buttonSection: {
    flexDirection: 'row',
    borderColor: _constants.colors.separator,
    borderTopWidth: 1
  }
});

exports.styles = styles;
//# sourceMappingURL=styles.js.map