"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useDebugItems = exports.resetLogItems = exports.getId = exports.addLogItem = void 0;

var _react = require("react");

var _state = require("../state");

var _findDiff = require("./findDiff");

let currentDebugItems = [];
const callbacks = {};

const resetLogItems = () => {
  currentDebugItems = [];
  Object.values(callbacks).forEach(callback => {
    callback === null || callback === void 0 ? void 0 : callback(currentDebugItems);
  });
};

exports.resetLogItems = resetLogItems;

const addLogItem = function () {
  if (!_state.DebuggerState.isMounted) return;
  let snapshot;

  if (_state.DebuggerState.areSnapshotsEnabled && _state.DebuggerState.getGlobalState) {
    const newSnapshot = _state.DebuggerState.getGlobalState();

    if (_state.DebuggerState.previousSnapshot) {
      snapshot = (0, _findDiff.findDiff)(_state.DebuggerState.previousSnapshot, newSnapshot);
    } else {
      snapshot = newSnapshot;
    }

    _state.DebuggerState.previousSnapshot = newSnapshot;
  }

  for (var _len = arguments.length, newItems = new Array(_len), _key = 0; _key < _len; _key++) {
    newItems[_key] = arguments[_key];
  }

  const normalizedItems = newItems.map(item => item && typeof item === 'object' ? {
    label: (item === null || item === void 0 ? void 0 : item.label) || (item === null || item === void 0 ? void 0 : item.title) || 'No description',
    id: getId(),
    logType: item.logType || 'info',
    type: item.type ?? undefined,
    data: (item === null || item === void 0 ? void 0 : item.data) || item,
    snapshot,
    timestamp: new Date().toISOString()
  } : {
    label: item,
    id: getId(),
    timestamp: new Date().toISOString(),
    logType: 'info',
    snapshot,
    type: undefined
  });
  currentDebugItems = [...normalizedItems, ...currentDebugItems];
  Object.values(callbacks).forEach(callback => {
    callback === null || callback === void 0 ? void 0 : callback(currentDebugItems);
  });
};

exports.addLogItem = addLogItem;

const getGenIdFn = () => {
  let lastId = 0;
  return () => `${lastId++}`;
};

const getId = getGenIdFn();
exports.getId = getId;

const getUseDebugItems = () => {
  return () => {
    const [debugItems, setDebugItems] = (0, _react.useState)(currentDebugItems);
    (0, _react.useEffect)(() => {
      const uid = getId();

      callbacks[uid] = newItems => setDebugItems(newItems);

      return () => {
        delete callbacks[uid];
      };
    }, []);
    return [debugItems, addLogItem];
  };
};

const useDebugItems = getUseDebugItems();
exports.useDebugItems = useDebugItems;
//# sourceMappingURL=useDebugItems.js.map