import { View, Text, FlatList, Pressable, ScrollView, Alert, Platform } from 'react-native';
import React, { useEffect, useState } from 'react';
import { resetLogItems, toggleDebugger, useDebugItems } from './utils';
import Clipboard from '@react-native-clipboard/clipboard';
import { useShowDebugger } from './utils/useShowDebugger';
import { DebuggerItem } from './components/DebuggerItem';
import { styles, itemColorByType } from './styles';
import { DebuggerState } from './state';
import { pickDirectory } from 'react-native-document-picker';
import { writeFile } from 'react-native-saf-x';
import RnBlobUtil from 'react-native-blob-util';
export * from './utils';
export * from './components';
export function multiply(a, b) {
  return Promise.resolve(a * b);
}

const Item = _ref => {
  let {
    item
  } = _ref;
  const [visible, setVisible] = useState(false);

  const handleCopyPress = () => Clipboard.setString(JSON.stringify(item));

  const colorByType = itemColorByType(item.logType);
  const textColor = {
    color: colorByType
  };
  const iconColor = {
    backgroundColor: colorByType
  };
  return /*#__PURE__*/React.createElement(View, {
    style: styles.itemWrapper
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.itemHeader
  }, /*#__PURE__*/React.createElement(View, {
    style: [styles.itemIcon, iconColor]
  }), /*#__PURE__*/React.createElement(View, null, /*#__PURE__*/React.createElement(Text, {
    selectable: true,
    style: [styles.itemLabel, textColor]
  }, item.label), /*#__PURE__*/React.createElement(Text, {
    selectable: true,
    style: [styles.itemTime, textColor]
  }, item.timestamp), Boolean(item.type) && /*#__PURE__*/React.createElement(Text, {
    selectable: true,
    style: [styles.itemType, textColor]
  }, item.type))), /*#__PURE__*/React.createElement(ScrollView, {
    style: visible ? styles.itemScrollWrapperVisible : styles.itemScrollWrapper,
    contentContainerStyle: item.itemScroll,
    horizontal: true
  }, /*#__PURE__*/React.createElement(DebuggerItem, {
    onToggle: setVisible,
    item: item.data
  })), visible && /*#__PURE__*/React.createElement(Pressable, {
    onPress: handleCopyPress,
    style: styles.itemCopyBtn
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.itemCopyText
  }, "Copy")));
};

const Separator = () => /*#__PURE__*/React.createElement(View, {
  style: styles.separator
});

const EmptySection = () => /*#__PURE__*/React.createElement(View, {
  style: styles.emptyWrapper
}, /*#__PURE__*/React.createElement(Text, {
  style: styles.emptyText
}, "No events captured yet"));

const keyExtractor = _ref2 => {
  let {
    id
  } = _ref2;
  return `${id}`;
};

const renderItem = _ref3 => {
  let {
    item
  } = _ref3;
  return /*#__PURE__*/React.createElement(Item, {
    item: item
  });
};

export const Debugger = /*#__PURE__*/React.memo(_ref4 => {
  let {
    getGlobalState
  } = _ref4;
  const [debugItems] = useDebugItems();
  const [show] = useShowDebugger();
  console.log({
    debugItems
  });
  useEffect(() => {
    DebuggerState.isMounted = true;
    return () => {
      DebuggerState.isMounted = false;
    };
  }, []);
  useEffect(() => {
    DebuggerState.getGlobalState = getGlobalState;
  }, [getGlobalState]);

  const handleClose = () => toggleDebugger(false);

  const handleGetGlobalState = () => getGlobalState && Clipboard.setString(JSON.stringify(getGlobalState === null || getGlobalState === void 0 ? void 0 : getGlobalState()));

  const handleExportItems = async () => {
    try {
      /*fetch('https://pastebin.com/api/api_post.php', {
        body: `api_dev_key=clcVbOdfoqzhASuaHaFSLXaiG78XAeRz&api_paste_code=${JSON.stringify(
          debugItems
        )}&api_option=paste&api_paste_private=2&api_user_key=37eb3c9cdd035fbb30c3f1b5a9e4b69b`,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded',
        },
        method: 'POST',
      })
        .then((d) => d.text())
        .then((url) => {
          Clipboard.setString(url);
          Alert.alert(url);
        });*/
      pickDirectory().then(dir => {
        var _dir$uri;

        if (!dir) {
          Clipboard.setString(JSON.stringify(debugItems));
          Alert.alert('File saving failed, copied instead');
          return;
        }

        const filePath = `${dir.uri}/qa-debugger-${new Date().toISOString()}.txt`;
        console.log({
          filePath
        });

        if (Platform.OS === 'android' && (_dir$uri = dir.uri) !== null && _dir$uri !== void 0 && _dir$uri.startsWith('content://')) {
          writeFile(filePath, JSON.stringify(debugItems)).then(() => {
            Alert.alert('File successfully saved');
          }).catch(() => {
            Clipboard.setString(JSON.stringify(debugItems));
            Alert.alert('File saving failed, copied instead');
          });
          return;
        }

        RnBlobUtil.fs.writeFile(filePath, JSON.stringify(debugItems), 'utf8').then(() => {
          Alert.alert('File successfully saved');
        }).catch(() => {
          Clipboard.setString(JSON.stringify(debugItems));
          Alert.alert('File saving failed, copied instead');
        });
      }).catch(() => {
        Clipboard.setString(JSON.stringify(debugItems));
        Alert.alert('Failed to pick a directory, copied instead');
      });
    } catch {
      Clipboard.setString(JSON.stringify(debugItems));
      Alert.alert('Items copied');
    }
  };

  return show ? /*#__PURE__*/React.createElement(View, {
    style: styles.wrapper
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.titleWrapper
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.title
  }, "QA DEBUGGER")), /*#__PURE__*/React.createElement(FlatList, {
    keyExtractor: keyExtractor,
    contentContainerStyle: styles.flex,
    ItemSeparatorComponent: Separator,
    data: debugItems,
    ListEmptyComponent: EmptySection,
    renderItem: renderItem
  }), /*#__PURE__*/React.createElement(View, {
    style: styles.buttonSection
  }, /*#__PURE__*/React.createElement(Pressable, {
    onPress: handleExportItems,
    style: styles.button
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.buttonText
  }, "Export items")), /*#__PURE__*/React.createElement(Pressable, {
    onPress: resetLogItems,
    style: [styles.button, styles.centralButton]
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.buttonText
  }, "Clear")), /*#__PURE__*/React.createElement(Pressable, {
    onPress: handleClose,
    style: styles.button
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.buttonText
  }, "Close"))), Boolean(getGlobalState) && /*#__PURE__*/React.createElement(View, {
    style: styles.buttonSection
  }, /*#__PURE__*/React.createElement(Pressable, {
    onPress: handleGetGlobalState,
    style: styles.button
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.buttonText
  }, "Copy global state")))) : null;
});
//# sourceMappingURL=index.js.map