import { useEffect, useState } from 'react';
import { DebuggerState } from '../state';
import { findDiff } from './findDiff';
let currentDebugItems = [];
const callbacks = {};
export const resetLogItems = () => {
  currentDebugItems = [];
  Object.values(callbacks).forEach(callback => {
    callback === null || callback === void 0 ? void 0 : callback(currentDebugItems);
  });
};
export const addLogItem = function () {
  if (!DebuggerState.isMounted) return;
  let snapshot;

  if (DebuggerState.areSnapshotsEnabled && DebuggerState.getGlobalState) {
    const newSnapshot = DebuggerState.getGlobalState();

    if (DebuggerState.previousSnapshot) {
      snapshot = findDiff(DebuggerState.previousSnapshot, newSnapshot);
    } else {
      snapshot = newSnapshot;
    }

    DebuggerState.previousSnapshot = newSnapshot;
  }

  for (var _len = arguments.length, newItems = new Array(_len), _key = 0; _key < _len; _key++) {
    newItems[_key] = arguments[_key];
  }

  const normalizedItems = newItems.map(item => item && typeof item === 'object' ? {
    label: (item === null || item === void 0 ? void 0 : item.label) || (item === null || item === void 0 ? void 0 : item.title) || 'No description',
    id: getId(),
    logType: item.logType || 'info',
    type: item.type ?? undefined,
    data: (item === null || item === void 0 ? void 0 : item.data) || item,
    snapshot,
    timestamp: new Date().toISOString()
  } : {
    label: item,
    id: getId(),
    timestamp: new Date().toISOString(),
    logType: 'info',
    snapshot,
    type: undefined
  });
  currentDebugItems = [...normalizedItems, ...currentDebugItems];
  Object.values(callbacks).forEach(callback => {
    callback === null || callback === void 0 ? void 0 : callback(currentDebugItems);
  });
};

const getGenIdFn = () => {
  let lastId = 0;
  return () => `${lastId++}`;
};

export const getId = getGenIdFn();

const getUseDebugItems = () => {
  return () => {
    const [debugItems, setDebugItems] = useState(currentDebugItems);
    useEffect(() => {
      const uid = getId();

      callbacks[uid] = newItems => setDebugItems(newItems);

      return () => {
        delete callbacks[uid];
      };
    }, []);
    return [debugItems, addLogItem];
  };
};

export const useDebugItems = getUseDebugItems();
//# sourceMappingURL=useDebugItems.js.map